@@ -1,4 +1,4 @@
-/*      $Id: client.h 24169 2006-12-22 20:21:05Z olivier $
+/*      $Id: client.h 24716 2007-01-24 21:42:47Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -273,6 +273,8 @@ struct _Client
     unsigned long xfwm_flags;
     /* Timout for asynchronous icon update */
     guint icon_timeout_id;
+    /* Timout for asynchronous frame update */
+    guint frame_timeout_id;
     /* Timout to manage blinking decorations for urgent windows */
     guint blink_timeout_id;
     /* Opacity for the compositor */
@@ -329,6 +331,7 @@ void                     clientFrameAll                         (ScreenInfo *);
 void                     clientUnframeAll                       (ScreenInfo *);
 void                     clientInstallColormaps                 (Client *);
 void                     clientUpdateColormaps                  (Client *);
+void                     clientUpdateName                       (Client *);
 void                     clientUpdateAllFrames                  (ScreenInfo *, 
                                                                  gboolean);
 void                     clientGrabButtons                      (Client *);
