@@ -1,4 +1,4 @@
-/*      $Id: compositor.c 23373 2006-10-12 20:22:20Z olivier $
+/*      $Id: compositor.c 24290 2007-01-07 18:54:42Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -67,17 +67,19 @@
 #define WIN_HAS_CLIENT(cw)              (cw->c)
 #define WIN_HAS_FRAME(cw)               (WIN_HAS_CLIENT(cw) && FLAG_TEST (cw->c->xfwm_flags, XFWM_FLAG_HAS_BORDER) && \
                                          !FLAG_TEST (cw->c->flags, CLIENT_FLAG_FULLSCREEN))
-#define WIN_NO_SHADOW(cw)               ((cw->c) &&  FLAG_TEST (cw->c->flags, CLIENT_FLAG_FULLSCREEN | CLIENT_FLAG_BELOW))
+#define WIN_NO_SHADOW(cw)               ((cw->c) && \
+                                           (FLAG_TEST (cw->c->flags, CLIENT_FLAG_FULLSCREEN | CLIENT_FLAG_BELOW) || \
+                                              (cw->c->type & (WINDOW_DOCK | WINDOW_DESKTOP))))
 #define WIN_IS_OVERRIDE(cw)             (cw->attr.override_redirect)
 #define WIN_IS_ARGB(cw)                 (cw->argb)
 #define WIN_IS_OPAQUE(cw)               (((cw->opacity == NET_WM_OPAQUE) && !WIN_IS_ARGB(cw)) || (cw->screen_info->overlays))
 #define WIN_IS_NATIVE_OPAQUE(cw)        ((cw->native_opacity) && !WIN_IS_ARGB(cw))
 #define WIN_IS_FULLSCREEN(cw)           ((cw->attr.x <= 0) && \
-                                         (cw->attr.y <= 0) && \
-                                         (cw->attr.width >= cw->screen_info->width) && \
-                                         (cw->attr.height >= cw->screen_info->height))
+                                           (cw->attr.y <= 0) && \
+                                           (cw->attr.width >= cw->screen_info->width) && \
+                                           (cw->attr.height >= cw->screen_info->height))
 #define WIN_IS_SHAPED(cw)               ((WIN_HAS_CLIENT(cw) && FLAG_TEST (cw->c->flags, CLIENT_FLAG_HAS_SHAPE)) || \
-                                         (WIN_IS_OVERRIDE(cw) && (cw->shaped)))
+                                           (WIN_IS_OVERRIDE(cw) && (cw->shaped)))
 #define WIN_IS_VIEWABLE(cw)             (cw->viewable)
 #define WIN_HAS_DAMAGE(cw)              (cw->damage)
 #define WIN_IS_VISIBLE(cw)              (WIN_IS_VIEWABLE(cw) && WIN_HAS_DAMAGE(cw))
@@ -724,22 +726,16 @@ free_win_data (CWindow *cw, gboolean delete)
         cw->alphaBorderPict = None;
     }
 
-    if (cw->clientSize)
-    {
-        XFixesDestroyRegion (display_info->dpy, cw->clientSize);
-        cw->clientSize = None;
-    }
-
     if (cw->borderSize)
     {
         XFixesDestroyRegion (display_info->dpy, cw->borderSize);
         cw->borderSize = None;
     }
 
-    if (cw->extents)
+    if (cw->clientSize)
     {
-        XFixesDestroyRegion (display_info->dpy, cw->extents);
-        cw->extents = None;
+        XFixesDestroyRegion (display_info->dpy, cw->clientSize);
+        cw->clientSize = None;
     }
 
     if (cw->borderClip)
@@ -748,9 +744,15 @@ free_win_data (CWindow *cw, gboolean delete)
         cw->borderClip = None;
     }
 
+    if (cw->extents)
+    {
+        XFixesDestroyRegion (display_info->dpy, cw->extents);
+        cw->extents = None;
+    }
+
     if (delete)
     {
-        if (cw->damage != None)
+        if (cw->damage)
         {
             XDamageDestroy (display_info->dpy, cw->damage);
             cw->damage = None;
@@ -1122,7 +1124,12 @@ paint_win (CWindow *cw, XserverRegion region, gboolean solid_part)
                                          * screen_info->params->frame_opacity
                                          / (NET_WM_OPAQUE * 100.0);
 
-                cw->alphaBorderPict = solid_picture (screen_info, FALSE, frame_opacity, 0, 0, 0);
+                cw->alphaBorderPict = solid_picture (screen_info, 
+                                                     FALSE, 
+                                                     frame_opacity, 
+                                                     0.0, /* red   */ 
+                                                     0.0, /* green */ 
+                                                     0.0  /* blue  */);
             }
 
             /* Top Border (title bar) */
@@ -1348,7 +1355,10 @@ paint_all (ScreenInfo *screen_info, XserverRegion region)
             if ((cw->opacity != NET_WM_OPAQUE) && !(cw->alphaPict))
             {
                 cw->alphaPict = solid_picture (screen_info, FALSE,
-                                               (double) cw->opacity / NET_WM_OPAQUE, 0, 0, 0);
+                                               (double) cw->opacity / NET_WM_OPAQUE,  
+                                               0.0, /* red   */ 
+                                               0.0, /* green */ 
+                                               0.0  /* blue  */);
             }
             XFixesIntersectRegion (dpy, cw->borderClip, cw->borderClip, cw->borderSize);
             XFixesSetPictureClipRegion (dpy, screen_info->rootBuffer, 0, 0, cw->borderClip);
@@ -1505,6 +1515,7 @@ add_damage (ScreenInfo *screen_info, XserverRegion damage)
         screen_info->allDamage = damage;
     }
 
+    /* The per-screen allDamage region is freed by repair_screen () */
     add_repair (screen_info->display_info);
 }
 
@@ -1555,7 +1566,7 @@ fix_region (CWindow *cw, XserverRegion region)
 }
 
 static void
-repair_win (CWindow *cw)
+repair_win (CWindow *cw, XRectangle *r)
 {
     DisplayInfo *display_info;
     ScreenInfo *screen_info;
@@ -1576,6 +1587,7 @@ repair_win (CWindow *cw)
     if (cw->damaged)
     {
         parts = XFixesCreateRegion (display_info->dpy, NULL, 0);
+        /* Copy the damage region to parts, subtracting it from the window's damage */
         XDamageSubtract (display_info->dpy, cw->damage, None, parts);
         XFixesTranslateRegion (display_info->dpy, parts,
                                cw->attr.x + cw->attr.border_width,
@@ -1584,12 +1596,14 @@ repair_win (CWindow *cw)
     else
     {
         parts = win_extents (cw);
+        /* Subtract all damage from the window's damage */
         XDamageSubtract (display_info->dpy, cw->damage, None, None);
     }
 
     if (parts)
     {
         fix_region (cw, parts);
+        /* parts region will be destroyed by add_damage () */
         add_damage (cw->screen_info, parts);
         cw->damaged = TRUE;
     }
@@ -1608,7 +1622,7 @@ damage_screen (ScreenInfo *screen_info)
     r.width = screen_info->width;
     r.height = screen_info->height;
     region = XFixesCreateRegion (display_info->dpy, &r, 1);
-    /* Region will be freed by add_damage () */
+    /* region will be freed by add_damage () */
     add_damage (screen_info, region);
 }
 
@@ -1622,6 +1636,7 @@ damage_win (CWindow *cw)
 
     extents = win_extents (cw);
     fix_region (cw, extents);
+    /* extents region will be freed by add_damage () */
     add_damage (cw->screen_info, extents);
 }
 
@@ -1705,7 +1720,7 @@ expose_area (ScreenInfo *screen_info, XRectangle *rects, gint nrects)
 
     display_info = screen_info->display_info;
     region = XFixesCreateRegion (display_info->dpy, rects, nrects);
-    /* damage region will be destroyed by add_damage () */
+    /* region will be destroyed by add_damage () */
     add_damage (screen_info, region);
 }
 
@@ -2003,16 +2018,6 @@ restack_win (CWindow *cw, Window above)
     }
 }
 
-static void
-set_size_attributes (CWindow *cw, gint x, gint y, gint width, gint height, gint bw)
-{
-    cw->attr.x = x;
-    cw->attr.y = y;
-    cw->attr.width = width;
-    cw->attr.height = height;
-    cw->attr.border_width = bw;
-}
-
 static void
 resize_win (CWindow *cw, gint x, gint y, gint width, gint height, gint bw, gboolean shape_notify)
 {
@@ -2026,16 +2031,24 @@ resize_win (CWindow *cw, gint x, gint y, gint width, gint height, gint bw, gbool
 
     screen_info = cw->screen_info;
     display_info = screen_info->display_info;
+    damage = None;
+
+    if (WIN_IS_VISIBLE(cw))
+    {
+        damage = XFixesCreateRegion (display_info->dpy, NULL, 0);
+        if (cw->extents)
+        {
+            XFixesCopyRegion (display_info->dpy, damage, cw->extents);
+        }
+    }
 
-    damage = XFixesCreateRegion (display_info->dpy, NULL, 0);
     if (cw->extents)
     {
-        XFixesCopyRegion (display_info->dpy, damage, cw->extents);
         XFixesDestroyRegion (display_info->dpy, cw->extents);
         cw->extents = None;
     }
 
-    if ((cw->attr.width != width) || (cw->attr.height != height))
+    if ((cw->attr.width != width) || (cw->attr.height != height) || shape_notify)
     {
 #if HAVE_NAME_WINDOW_PIXMAP
         if (cw->name_window_pixmap)
@@ -2044,10 +2057,6 @@ resize_win (CWindow *cw, gint x, gint y, gint width, gint height, gint bw, gbool
             cw->name_window_pixmap = None;
         }
 #endif
-    }
-
-    if ((cw->attr.width != width) || (cw->attr.height != height) || shape_notify)
-    {
         if (cw->picture)
         {
             XRenderFreePicture (display_info->dpy, cw->picture);
@@ -2077,25 +2086,26 @@ resize_win (CWindow *cw, gint x, gint y, gint width, gint height, gint bw, gbool
         }
     }
 
-    set_size_attributes (cw, x, y, width, height, bw);
+    cw->attr.x = x;
+    cw->attr.y = y;
+    cw->attr.width = width;
+    cw->attr.height = height;
+    cw->attr.border_width = bw;
 
-    if (!WIN_IS_VISIBLE(cw))
+    if (damage)
     {
-        /* 'nuff for invisible windows... */
-        return;
+        cw->extents = win_extents (cw);
+        XFixesUnionRegion (display_info->dpy, damage, damage, cw->extents);
+        /* A shape notify will likely change the shadows too, so clear the extents */
+        if (shape_notify)
+        {
+            XFixesDestroyRegion (display_info->dpy, cw->extents);
+            cw->extents = None;
+        }
+        fix_region (cw, damage);
+        /* damage region will be destroyed by add_damage () */
+        add_damage (screen_info, damage);
     }
-
-    cw->extents = win_extents (cw);
-    XFixesUnionRegion (display_info->dpy, damage, damage, cw->extents);
-    /* A shape notify will likely change the shadows too, so clear the extents */
-    if (shape_notify)
-    {
-        XFixesDestroyRegion (display_info->dpy, cw->extents);
-        cw->extents = None;
-    }
-    fix_region (cw, damage);
-    /* damage region will be destroyed by add_damage () */
-    add_damage (screen_info, damage);
 }
 
 static void
@@ -2129,11 +2139,25 @@ compositorHandleDamage (DisplayInfo *display_info, XDamageNotifyEvent *ev)
     g_return_if_fail (ev != NULL);
     TRACE ("entering compositorHandleDamage for 0x%lx", ev->drawable);
 
+    /*
+      ev->drawable is the window ID of the damaged window
+      ev->geometry is the geometry of the damaged window
+      ev->area     is the bounding rect for the damaged area
+      ev->damage   is the damage handle returned by XDamageCreate()
+     */
+
     cw = find_cwindow_in_display (display_info, ev->drawable);
     if ((cw) && WIN_IS_REDIRECTED(cw))
     {
-        repair_win (cw);
-        add_repair (display_info);
+        repair_win (cw, &ev->area);
+        display_info->damages_pending = ev->more;
+#ifdef USE_IDLE_REPAINT
+        /* If there are more damages to come, we'll schedule the repair later */
+        if (!display_info->damages_pending)
+        {
+            add_repair (display_info);
+        }
+#endif /* USE_IDLE_REPAINT */
     }
 }
 
@@ -2613,7 +2637,10 @@ compositorHandleEvent (DisplayInfo *display_info, XEvent *ev)
         compositorHandleShapeNotify (display_info, (XShapeEvent *) ev);
     }
 #ifndef USE_IDLE_REPAINT
-    repair_display (display_info);
+    if (!display_info->damages_pending)
+    {
+        repair_display (display_info);
+    }
 #endif /* USE_IDLE_REPAINT */
 
 #endif /* HAVE_COMPOSITOR */
@@ -2683,6 +2710,7 @@ compositorInitDisplay (DisplayInfo *display_info)
 
     display_info->compositor_idle_id = 0;
     display_info->compositor_timeout_id = 0;
+    display_info->damages_pending = FALSE;
 
     display_info->enable_compositor = ((display_info->have_render)
                                     && (display_info->have_composite)
@@ -2778,7 +2806,13 @@ compositorManageScreen (ScreenInfo *screen_info)
     screen_info->gaussianMap = make_gaussian_map(SHADOW_RADIUS);
     presum_gaussian (screen_info);
     screen_info->rootBuffer = None;
-    screen_info->blackPicture = solid_picture (screen_info, TRUE, 1, 0, 0, 0);
+    /* Change following argb values to play with shadow colors */
+    screen_info->blackPicture = solid_picture (screen_info, 
+                                               TRUE, 
+                                               1.0, /* alpha */ 
+                                               0.0, /* red   */ 
+                                               0.0, /* green */ 
+                                               0.0  /* blue  */);
     screen_info->rootTile = None;
     screen_info->allDamage = None;
     screen_info->cwindows = NULL;
