@@ -1,4 +1,4 @@
-/*      $Id: display.c 24107 2006-12-14 21:49:51Z olivier $
+/*      $Id: display.c 25831 2007-06-21 22:28:04Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -178,13 +178,24 @@ myDisplayInitAtoms (DisplayInfo *display_info)
                           FALSE, display_info->atoms) != 0);
 }
 
+static void
+myDisplayCreateTimestampWin (DisplayInfo *display_info)
+{
+    XSetWindowAttributes attributes;
+
+    attributes.event_mask = PropertyChangeMask;
+    attributes.override_redirect = TRUE;
+    display_info->timestamp_win = 
+        XCreateWindow (display_info->dpy, DefaultRootWindow (display_info->dpy),
+                       -100, -100, 10, 10, 0, 0, CopyFromParent, CopyFromParent,
+                       CWEventMask | CWOverrideRedirect, &attributes);
+}
+
 DisplayInfo *
 myDisplayInit (GdkDisplay *gdisplay)
 {
     DisplayInfo *display;
-#ifdef HAVE_XSYNC
-    int xsync_major, xsync_minor;
-#endif /* HAVE_XSYNC */
+    int major, minor;
     int dummy;
 
     display = g_new0 (DisplayInfo, 1);
@@ -205,11 +216,18 @@ myDisplayInit (GdkDisplay *gdisplay)
     }
 
     /* Test XShape extension support */
+    major = 0;
+    minor = 0;
+    display->shape_version = 0;
     if (XShapeQueryExtension (display->dpy,
                               &display->shape_event_base,
                               &dummy))
     {
         display->have_shape = TRUE;
+        if (XShapeQueryVersion (display->dpy, &major, &minor))
+        {
+            display->shape_version = major * 1000 + minor;
+        }
     }
     else
     {
@@ -224,15 +242,15 @@ myDisplayInit (GdkDisplay *gdisplay)
     display->xsync_error_base = 0;
     display->xsync_event_base = 0;
 
-    xsync_major = SYNC_MAJOR_VERSION;
-    xsync_minor = SYNC_MINOR_VERSION;
+    major = SYNC_MAJOR_VERSION;
+    minor = SYNC_MINOR_VERSION;
     
     if (XSyncQueryExtension (display->dpy,
                               &display->xsync_event_base,
                               &display->xsync_error_base)
          && XSyncInitialize (display->dpy, 
-                             &xsync_major, 
-                             &xsync_minor))
+                             &major, 
+                             &minor))
     {
         display->have_xsync = TRUE;
     }
@@ -304,6 +322,8 @@ myDisplayInit (GdkDisplay *gdisplay)
     display->resize_cursor[CORNER_COUNT + SIDE_BOTTOM] =
         XCreateFontCursor (display->dpy, XC_bottom_side);
 
+    myDisplayCreateTimestampWin (display);
+
     display->xfilter = NULL;
     display->screens = NULL;
     display->clients = NULL;
@@ -335,6 +355,8 @@ myDisplayClose (DisplayInfo *display)
     display->move_cursor = None;
     XFreeCursor (display->dpy, display->root_cursor);
     display->root_cursor = None;
+    XDestroyWindow (display->dpy, display->timestamp_win);
+    display->timestamp_win = None;
 
     if (display->hostname)
     {
