@@ -1,4 +1,4 @@
-/*      $Id: main.c 23584 2006-11-01 18:02:10Z olivier $
+/*      $Id: main.c 24099 2006-12-13 22:01:17Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 #include <config.h>
 #endif
 
+#include <X11/X.h>
 #include <X11/Xlib.h>
 #include <glib.h>
 #include <gdk/gdk.h>
@@ -400,7 +401,7 @@ initialize (int argc, char **argv, gint compositor_mode)
 
     TRACE ("entering initialize");
 
-    xfce_textdomain(GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
+    xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
 
     gtk_init (&argc, &argv);
 
@@ -410,8 +411,7 @@ initialize (int argc, char **argv, gint compositor_mode)
     ensure_basedir_spec ();
 
     initMenuEventWin ();
-    clientClearFocus ();
-
+    clientClearFocus (NULL);
     display_info = myDisplayInit (gdk_display_get_default ());
 
 #ifdef HAVE_COMPOSITOR
@@ -440,13 +440,13 @@ initialize (int argc, char **argv, gint compositor_mode)
     sigaction (SIGUSR1, &act, NULL);
     sigaction (SIGSEGV, &act, NULL);
 
-    nscreens = gdk_display_get_n_screens(display_info->gdisplay);
+    nscreens = gdk_display_get_n_screens (display_info->gdisplay);
     for(i = 0; i < nscreens; i++)
     {
         ScreenInfo *screen_info;
         GdkScreen *gscr;
 
-        gscr = gdk_display_get_screen(display_info->gdisplay, i);
+        gscr = gdk_display_get_screen (display_info->gdisplay, i);
         screen_info = myScreenInit (display_info, gscr, MAIN_EVENT_MASK);
 
         if (!screen_info)
@@ -505,8 +505,7 @@ initialize (int argc, char **argv, gint compositor_mode)
                                    screen_info->width,
                                    screen_info->height);
         workspaceUpdateArea (screen_info);
-        XSetInputFocus (display_info->dpy, screen_info->xfwm4_win, RevertToPointerRoot, 
-                        myDisplayGetCurrentTime (display_info));
+        XSetInputFocus (display_info->dpy, screen_info->xfwm4_win, RevertToPointerRoot, CurrentTime);
 
         clientFrameAll (screen_info);
 
@@ -550,12 +549,12 @@ main (int argc, char **argv)
             compositor = parse_compositor (argv[i]);
         }
 #endif /* HAVE_COMPOSITOR */
-        else if (!strcmp(argv[i], "--version") || !strcmp(argv[i], "-V"))
+        else if (!strcmp (argv[i], "--version") || !strcmp (argv[i], "-V"))
         {
             print_version ();
             exit (0);
         }
-        else if (!strcmp(argv[i], "--help") || !strcmp(argv[i], "-H"))
+        else if (!strcmp (argv[i], "--help") || !strcmp (argv[i], "-H"))
         {
             print_usage ();
             exit (0);
@@ -582,9 +581,9 @@ main (int argc, char **argv)
             if (daemon_mode)
             {
 #ifdef HAVE_DAEMON
-                if (daemon(TRUE, TRUE) < 0)
+                if (daemon (TRUE, TRUE) < 0)
                 {
-                        g_warning("Failed to enter daemon mode: %s", g_strerror(errno));
+                        g_warning ("Failed to enter daemon mode: %s", g_strerror(errno));
                         exit(EXIT_FAILURE);
                 }
 #else /* !HAVE_DAEMON */
