@@ -1,4 +1,4 @@
-/*      $Id: screen.h 23704 2006-11-04 22:36:42Z olivier $
+/*      $Id: screen.h 24291 2007-01-07 20:23:21Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -160,16 +160,16 @@ Display                 *myScreenGetXDisplay                    (ScreenInfo *);
 GtkWidget               *myScreenGetGtkWidget                   (ScreenInfo *);
 GtkWidget               *myScreenGetGtkWidget                   (ScreenInfo *);
 GdkWindow               *myScreenGetGdkWindow                   (ScreenInfo *);
+gboolean                 myScreenCheckWMAtom                    (ScreenInfo *,
+                                                                 Atom atom);
 gboolean                 myScreenGrabKeyboard                   (ScreenInfo *,
                                                                  Time);
 gboolean                 myScreenGrabPointer                    (ScreenInfo *,
                                                                  unsigned int,
                                                                  Cursor,
                                                                  Time);
-unsigned int             myScreenUngrabKeyboard                 (ScreenInfo *,
-                                                                 Time);
-unsigned int             myScreenUngrabPointer                  (ScreenInfo *,
-                                                                 Time);
+unsigned int             myScreenUngrabKeyboard                 (ScreenInfo *);
+unsigned int             myScreenUngrabPointer                  (ScreenInfo *);
 void                     myScreenGrabKeys                       (ScreenInfo *);
 void                     myScreenUngrabKeys                     (ScreenInfo *);
 #endif /* INC_SCREEN_H */
