@@ -1,4 +1,4 @@
-/*      $Id: stacking.c 24107 2006-12-14 21:49:51Z olivier $
+/*      $Id: stacking.c 25627 2007-04-22 21:04:34Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -154,7 +154,8 @@ gboolean
 clientIsTopMost (Client *c)
 {
     ScreenInfo *screen_info;
-    GList *index;
+    GList *index, *index2;
+    Client *c2;
 
     g_return_val_if_fail (c != NULL, FALSE);
     TRACE ("entering clientIsTopMost");
@@ -164,18 +165,18 @@ clientIsTopMost (Client *c)
     index = g_list_find (screen_info->windows_stack, (gconstpointer) c);
     if (index)
     {
-        GList *index2 = g_list_next (index);
-        if (index2)
+        index2 = g_list_next (index);
+        while (index2)
         {
-            Client *c2 = (Client *) index2->data;
-            return (c2->win_layer > c->win_layer);
-        }
-        else
-        {
-            return TRUE;
+            c2 = (Client *) index2->data;
+            if (FLAG_TEST (c2->xfwm_flags, XFWM_FLAG_VISIBLE) && (c2->win_layer == c->win_layer))
+            {
+                return FALSE;
+            }
+            index2 = g_list_next (index2);
         }
     }
-    return FALSE;
+    return TRUE;
 }
 
 Client *
@@ -252,8 +253,8 @@ clientAtPosition (ScreenInfo *screen_info, int x, int y, Client * exclude)
     for (index = g_list_last (screen_info->windows_stack); index; index = g_list_previous (index))
     {
         c2 = (Client *) index->data;
-        if ((frameX (c2) < x) && (frameX (c2) + frameWidth (c2) > x)
-            && (frameY (c2) < y) && (frameY (c2) + frameHeight (c2) > y))
+        if ((frameX (c2) <= x) && (frameX (c2) + frameWidth (c2) >= x)
+            && (frameY (c2) <= y) && (frameY (c2) + frameHeight (c2) >= y))
         {
             if (clientSelectMask (c2, INCLUDE_SKIP_PAGER | INCLUDE_SKIP_TASKBAR, WINDOW_REGULAR_FOCUSABLE)
                 && (c2 != exclude))
